/*
 *  jQuery AJAX :
 *      Premiers dialogues client-serveur asynchrone avec jQuery
 *
 *  Auteur :
 *      N. Chabloz
 *
 */

$("document").ready(function(){
    getHelloHtml();
    getHelloTxt();
    getHelloXml();
    getHelloJson();
    
});

/* AJAX avec un retour serveur "brute de HTML"
 *
 * C'est l'utilisation la plus simple, avec un retour comme fragment HTML
 * prêt à être injecter dans le document.
 * 
 * La particularité de cette fonction est d'injecter directement le retour dans le DOM.
 *
 * Notons qu'il est néanmoins possible d'envoyer des paramètres et
 * de déclencher une fonction de rappel si nécessaire.
 *
 */

function getHelloHtml() {
    $("#container").load("data/hello.html");
}

/* AJAX avec un retour serveur en "texte brute"
 *
 * La réponse du serveur est du texte sans formattage particulier, il n'y a donc
 * aucun moyen de différencier les informations reçues entre elles. Elles sont
 * donc gérées comme une seule entité.
 *
 * Vous pouvez utiliser les méthodes get ou post pour faire une requête au
 * serveur ou vous pouvez utiliser la méthode plus complète (mais plus complexe)
 * ajax. (Pour plus de détail: http://docs.jquery.com/Ajax )
 *
 * les {} servent à transmettre des données au serveur, dans les exemples
 * suivant, les accolades restent vide car aucune donnée n'est transmise.
 *
 * La fonction de rappel est ici primordiale car c'est elle qui décide ce qui
 * est fait avec le contenu reçu (ici une simple insertion dans le DOM).
 * 
 */
function getHelloTxt(){
    $.get('data/hello.txt', {}, function (data){
        $("#container").append(data);
    });
}

/* AJAX avec un retour serveur en XML
 *
 * La réponse du serveur est du XML. Grâce au balisage, nous pouvons donc gérer
 * des résultats multiples du serveur (il existe une structure).
 * 
 * Dans l'exemple, chaque balise <texte> du XML est converti en un <div>
 * dans le DOM de la page XHTML.
 *
 * L'exemple montre aussi comment utiliser les fonctionnalités DOM de jQuery sur
 * autre chose que du HTML. Ici jQuery est utilisé sur le DOM du XML envoyé par
 * le serveur. $("texte", xml) retourne alors toutes les balise <texte> du XML
 * et la méthode text() retourne le contenu textuelle du noeud.
 *
 * Aussi, nous utilisons ici la méthode "each" à la place d'une traditionnelle
 * boucle for. C'est donc une itération explicite (http://api.jquery.com/each/).
 * 
 */
function getHelloXml(){
    $.post('data/hello.xml', {}, function (xml){
        $("texte", xml).each(function(i, e){
            var newDiv = $("<div>"+$(e).text()+"</div>");
            newDiv.addClass("color"+i).appendTo($("#container"));
        });
    });   
}

/* AJAX avec un retour serveur en JSON
 *
 * La réponse du serveur est au format JSON ( http://json.org/json-fr.html ).
 * il est possble de recevoir du serveur directement une structure de
 * données. JSON permet donc de transmettre directement du serveur vers le
 * client toute une structure de données complexe comme un tableau, un objet
 * (seul ses attributs seront transférés) ou autre. La plupart du temps le
 * serveur retourne un tableau, un objet ou une combinaison des deux. Voilà un
 * exemple de retour serveur en JSON:
 *
 * http://api.flickr.com/services/feeds/photos_public.gne?tags=bird&format=json
 *
 * Pour l'exemple ci-dessous le JSON reçu est simplement un tableau classique.
 * Nous pouvons utiliser la fonction globale "each" de jQuery pour itérer sur les
 * élément du tableau.
 * 
 */
function getHelloJson(){
    $.getJSON('data/hello.json', {}, function (data){
        $.each(data, function(i,item){
            var newDiv = $("<div>"+item+"</div>");
            newDiv.addClass("color"+i).appendTo($("#container"));
        });
    });
}